##  Validation
After configuring both automations, validate the implementation using the following test scenarios:
  1. Set an initiative's End of Life date to yesterday and wait for the nightly check.
  2. Create a new application and link it to an initiative with a past End of Life date.
  3. Create an application and link it to three initiatives: one with an End of Life reached and two that are active.
